@@ -1,3 +1,5 @@
+#' @rdname prepScores
+#' @export
 prepCox <- function(Z, formula, SNPInfo=NULL, snpNames = "Name", aggregateBy = "gene", data=parent.frame(), verbose =FALSE){
   #require(survival)
   env <- environment()
@@ -5,6 +7,8 @@ prepCox <- function(Z, formula, SNPInfo=NULL, snpNames = "Name", aggregateBy = "
     warning("No SNP Info file provided: loading the Illumina HumanExome BeadChip. See ?SNPInfo for more details")
     load(paste(find.package("skatMeta"), "data", "SNPInfo.rda",sep = "/"))
     aggregateBy = "SKATgene"
+  } else {
+    SNPInfo <- prepSNPInfo(SNPInfo, snpNames, aggregateBy)
   }
   
   #fit null model: 
